summaryrefslogtreecommitdiff
path: root/src/being.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/being.h')
-rw-r--r--src/being.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/being.h b/src/being.h
index 3479a9a8..3d3dfa71 100644
--- a/src/being.h
+++ b/src/being.h
@@ -118,11 +118,11 @@ class Being : public Sprite, public ConfigListener
/**
* Constructor.
*
* @param id a unique being id
* @param job partly determines the type of the being
* @param map the map the being is on
*/
- Being(int id, int job, Map *map);
+ Being(int id, int subtype, Map *map);
virtual ~Being();
@@ -284,12 +284,12 @@ class Being : public Sprite, public ConfigListener
/**
* Return Being's current Job (player job, npc, monster, creature )
*/
- Uint16 getJob() const { return mJob; }
+ Uint16 getSubType() const { return mSubType; }
/**
* Set Being's current Job (player job, npc, monster, creature )
*/
- void setJob(Uint16 job) { mJob = job; }
+ virtual void setSubtype(Uint16 subtype) { mSubType = subtype; }
/**
* Sets the walk speed.
@@ -611,7 +611,7 @@ class Being : public Sprite, public ConfigListener
int mAttackSpeed; /**< Attack speed */
Action mAction; /**< Action the being is performing */
- Uint16 mJob; /**< Job (player job, npc, monster, creature ) */
+ Uint16 mSubType; /**< Subtype (graphical view, basically) */
int mId; /**< Unique sprite id */
Uint8 mDirection; /**< Facing direction */
@@ -118,11 +118,11 @@ class Being : public Sprite, public ConfigListener
* Constructor.
*
- * @param id a unique being id
- * @param job partly determines the type of the being
- * @param map the map the being is on
+ * @param id a unique being id
+ * @param subtype partly determines the type of the being
+ * @param map the map the being is on
*/